=== modified file 'daemons/poppy-sftp.tac'
--- daemons/poppy-sftp.tac	2011-05-10 13:56:21 +0000
+++ daemons/poppy-sftp.tac	2011-12-09 06:24:02 +0000
@@ -6,6 +6,7 @@
 # or similar.  Refer to the twistd(1) man page for details.
 
 import logging
+import sys
 
 from twisted.application import service
 from twisted.conch.interfaces import ISession
@@ -13,6 +14,7 @@
 from twisted.cred.portal import IRealm, Portal
 from twisted.protocols.policies import TimeoutFactory
 from twisted.python import components
+from twisted.scripts.twistd import ServerOptions
 from twisted.web.xmlrpc import Proxy
 
 from zope.interface import implements
@@ -31,6 +33,7 @@
     LaunchpadAvatar, PublicKeyFromLaunchpadChecker)
 from lp.services.sshserver.service import SSHService
 from lp.services.sshserver.session import DoNothingSession
+from lp.services.twistedsupport.loggingsupport import set_up_oops_reporting
 
 
 def make_portal():
@@ -70,9 +73,11 @@
     return SFTPServer(avatar, get_poppy_root())
 
 
-# Connect Python logging to Twisted's logging.
-from lp.services.twistedsupport.loggingsupport import set_up_tacfile_logging
-set_up_tacfile_logging("poppy-sftp", logging.INFO)
+# Force python logging to all go to the Twisted log.msg interface. The default
+# - output on stderr - will not be watched by anyone.
+from twisted.python import log
+stream = log.StdioOnnaStick()
+logging.basicConfig(stream=stream, level=logging.INFO)
 
 
 components.registerAdapter(
@@ -86,7 +91,12 @@
 
 # Construct an Application that has the Poppy SSH server,
 # and the Poppy FTP server.
+options = ServerOptions()
+options.parseOptions()
 application = service.Application('poppy-sftp')
+observer = set_up_oops_reporting(
+    'poppy-sftp', 'poppy', options.get('logfile'))
+application.addComponent(observer, ignoreClass=1)
 
 ftpservice.setServiceParent(application)
 

=== modified file 'lib/lp/services/sshserver/service.py'
--- lib/lp/services/sshserver/service.py	2011-10-27 11:36:13 +0000
+++ lib/lp/services/sshserver/service.py	2011-12-09 06:24:02 +0000
@@ -171,7 +171,7 @@
             logging.getLogger(self._access_log_path),
             self._access_log_path)
         manager.setUp()
-        set_up_oops_reporting(self._main_log, self._oops_configuration)
+        # set_up_oops_reporting(self._main_log, self._oops_configuration)
         notify(events.ServerStarting())
         # By default, only the owner of files should be able to write to them.
         # Perhaps in the future this line will be deleted and the umask

=== modified file 'lib/lp/services/twistedsupport/loggingsupport.py'
--- lib/lp/services/twistedsupport/loggingsupport.py	2011-10-14 04:40:49 +0000
+++ lib/lp/services/twistedsupport/loggingsupport.py	2011-12-09 06:24:02 +0000
@@ -42,45 +42,27 @@
     This also configures oops reporting to use the section named
     'name'."""
     logger_object = logger(options, name)
-    set_up_oops_reporting(name, name, mangle_stdout=True)
+    observer = set_up_oops_reporting(name, name)
+    log.startLoggingWithObserver(observer)
     return logger_object
 
 
-def set_up_tacfile_logging(name, level):
-    """Create a `Logger` object for use in tac files.
-
-    This is preferable to use over `set_up_logging_for_script` for .tac
-    files since there's no options to pass through.  The logger object
-    is connected to Twisted's log and returned.
-
-    :param name: The logger instance name.
-    :param level: The log level to use, eg. logging.INFO or logging.DEBUG
-    """
-    logger = logging.getLogger(name)
-    channel = logging.StreamHandler(log.StdioOnnaStick())
-    channel.setLevel(level)
-    channel.setFormatter(logging.Formatter('%(message)s'))
-    logger.addHandler(channel)
-    logger.setLevel(level)
-    return logger
-
-
-def set_up_oops_reporting(name, configuration, mangle_stdout=True):
+def set_up_oops_reporting(name, configuration, logfile):
     """Set up OOPS reporting by starting the Twisted logger with an observer.
 
     :param name: The name of the logger to use for oops reporting.
     :param configuration: The name of the config section to use for oops
         reporting.
-    :param mangle_stdout: If True, send stdout and stderr to the logger.
-        Defaults to False.
+    :param logfile: File to log output to.
     """
     errorlog.globalErrorUtility.configure(
         configuration,
         config_factory=oops_twisted.Config,
         publisher_adapter=oops_twisted.defer_publisher)
+    log_observer = RotatableFileLogObserver(logfile)
     oops_observer = OOPSObserver(errorlog.globalErrorUtility._oops_config,
-        log.PythonLoggingObserver(loggerName=name).emit)
-    log.startLoggingWithObserver(oops_observer.emit, mangle_stdout)
+        log_observer)
+    return oops_observer
 
 
 class LaunchpadLogFile(DailyLogFile):

=== modified file 'versions.cfg'
--- versions.cfg	2011-12-09 04:27:11 +0000
+++ versions.cfg	2011-12-09 06:24:02 +0000
@@ -56,7 +56,7 @@
 oops-datedir-repo = 0.0.14
 oops-wsgi = 0.0.8
 oops-timeline = 0.0.1
-oops-twisted = 0.0.5
+oops-twisted = 0.0.6
 ordereddict = 1.1
 paramiko = 1.7.4
 Paste = 1.7.2

